REST utilities — Django Kaos Utils documentation

# REST utilities

## Serializers

class dj_kaos_utils.rest.serializers.WritableNestedSerializer(*args, **kwargs)

  Bases: `ModelSerializer`

  WritableNestedSerializer functions as a ModelSerializer when serializing (retrieve and list) returning nested models. When deserializing, acts as a SlugRelatedField if data is a string (example UUID value) otherwise behaves as a writable nested serializer.